@@ -1,5 +1,5 @@
 import abc
-from typing import Any, List, Optional, Tuple, Type, overload, Literal, Union
+from typing import Any, List, Optional, Tuple, Type
 
 from .models import (
     DBIndex,
@@ -19,7 +19,11 @@ class BaseClient(abc.ABC):
 
     @abc.abstractmethod
     async def insert(
-        self, model: DocumentDBModel, include=None, exclude=None, session: Any = None,
+        self,
+        model: DocumentDBModel,
+        include=None,
+        exclude=None,
+        session: Any = None,
     ) -> WriteResult:
         pass
 
@@ -29,13 +33,19 @@ class BaseClient(abc.ABC):
 
     @abc.abstractmethod
     async def get_dict(
-        self, collection_name: str, _id: str, session: Any = None,
+        self,
+        collection_name: str,
+        _id: str,
+        session: Any = None,
     ) -> Optional[dict]:
         pass
 
     @abc.abstractmethod
     async def get(
-        self, model: Type[DocumentDBModel], _id: str, session: Any = None,
+        self,
+        model: Type[DocumentDBModel],
+        _id: str,
+        session: Any = None,
     ) -> Optional[DocumentDBModel]:
         pass
 
@@ -81,14 +91,16 @@ class BaseClient(abc.ABC):
         pass
 
     @abc.abstractmethod
-    async def delete(
-        self, model: Type[DocumentDBModel], _id: str, session: Any = None
-    ) -> DeleteResult:
+    async def delete(self, model: Type[DocumentDBModel], _id: str, session: Any = None) -> DeleteResult:
         pass
 
     @abc.abstractmethod
     async def update_one(
-        self, model: Type[DocumentDBModel], id: str, data: dict, session: Any = None,
+        self,
+        model: Type[DocumentDBModel],
+        id: str,
+        data: dict,
+        session: Any = None,
     ) -> WriteResult:
         pass
 
