@@ -13,9 +13,7 @@ from io import BytesIO
 dirname = os.path.dirname(__file__)
 
 
-async def create_workflow_project(
-    user_id: str, project_name: str, bucket_id: str = None
-) -> WorkflowProject:
+async def create_workflow_project(user_id: str, project_name: str, bucket_id: str = None) -> WorkflowProject:
     client = get_workflow_client()
     try:
         project = await client._get_project_by_name(user_id)
@@ -40,9 +38,7 @@ async def delete_workflow_project(user_id: str, project_name: str):
     try:
         await client.delete_branch(user_id, project_name)
     except ValueError:
-        LOG.error(
-            f"Trying to delete workflow project {project_name} does not exist for user {user_id}."
-        )
+        LOG.error(f"Trying to delete workflow project {project_name} does not exist for user {user_id}.")
         raise ValueError(f"Workflow Project {project_name} does not exist.")
 
 
@@ -71,10 +67,8 @@ async def retry_workflow(user_id: str, workflow_id: int) -> WorkflowRun:
     return await client.retry_pipeline(user_id, workflow_id)
 
 
-async def get_job_output(
-    bucket_id: str, workflow_id: int, job_id: int
-) -> Union[dict, List, None]:
-    client = get_workflow_client()
+async def get_job_output(bucket_id: str, workflow_id: int, job_id: int) -> Union[dict, List, None]:
+    # client = get_workflow_client()
     storage = get_storage_client()
     file = await storage.get_file(
         bucket_id,
@@ -100,18 +94,15 @@ async def get_job_file(
     )
 
 
-async def get_job_file_refs(
-    bucket_id: str, workflow_id: int, job_id: int
-) -> List[File]:
+async def get_job_file_refs(bucket_id: str, workflow_id: int, job_id: int) -> List[File]:
     storage = get_storage_client()
     return await storage.list_files(
-        bucket_id, f"{get_settings().WORKFLOW_UPLOAD_PATH}/{workflow_id}/{job_id}/",
+        bucket_id,
+        f"{get_settings().WORKFLOW_UPLOAD_PATH}/{workflow_id}/{job_id}/",
     )
 
 
-async def add_data_to_job(
-    job: JobRun, bucket_id: str, output: bool = True, file_refs: bool = True
-) -> JobRun:
+async def add_data_to_job(job: JobRun, bucket_id: str, output: bool = True, file_refs: bool = True) -> JobRun:
     if job.status == "success":
         if file_refs:
             job.files = await get_job_file_refs(bucket_id, job.workflow_id, job.id)
@@ -124,9 +115,7 @@ async def delete_workflow(user_id: str, bucket_id: str, workflow_id: int):
     client = get_workflow_client()
     await client.delete_pipeline(user_id, workflow_id)
     storage = get_storage_client()
-    await storage.delete_file(
-        bucket_id, f"{get_settings().WORKFLOW_UPLOAD_PATH}/{workflow_id}", True
-    )
+    await storage.delete_file(bucket_id, f"{get_settings().WORKFLOW_UPLOAD_PATH}/{workflow_id}", True)
 
 
 async def run_job(
@@ -156,12 +145,8 @@ async def run_job(
     job_yaml["run-job"]["variables"]["MODULE_NAME"] = module.name
     job_yaml["run-job"]["variables"]["KUBERNETES_CPU_REQUEST"] = module.cpu_request
     job_yaml["run-job"]["variables"]["KUBERNETES_CPU_LIMIT"] = module.cpu_limit
-    job_yaml["run-job"]["variables"][
-        "KUBERNETES_MEMORY_REQUEST"
-    ] = f"{module.memory_request_gb}Gi"
-    job_yaml["run-job"]["variables"][
-        "KUBERNETES_MEMORY_LIMIT"
-    ] = f"{module.memory_limit_gb}Gi"
+    job_yaml["run-job"]["variables"]["KUBERNETES_MEMORY_REQUEST"] = f"{module.memory_request_gb}Gi"
+    job_yaml["run-job"]["variables"]["KUBERNETES_MEMORY_LIMIT"] = f"{module.memory_limit_gb}Gi"
 
     if len(job_data) > 1:
         for i, params in enumerate(job_data):
@@ -170,14 +155,12 @@ async def run_job(
             job_yaml[f"run-job{i}"]["variables"]["JOB_PARAMETERS"] = json.dumps(params)
         del job_yaml["run-job"]
     else:
-        job_yaml[f"run-job"]["variables"]["JOB_PARAMETERS"] = json.dumps(job_data[0])
+        job_yaml["run-job"]["variables"]["JOB_PARAMETERS"] = json.dumps(job_data[0])
 
     if not upload:
         del job_yaml["upload-data"]
     else:
-        upload_uri = get_storage_client().get_uri(
-            project.bucket_id, settings.WORKFLOW_UPLOAD_PATH
-        )
+        upload_uri = get_storage_client().get_uri(project.bucket_id, settings.WORKFLOW_UPLOAD_PATH)
         job_yaml["upload-data"]["variables"]["UPLOAD_PATH"] = upload_uri
         if upload_runner is None:
             upload_runner = runner
@@ -185,9 +168,7 @@ async def run_job(
 
     client = get_workflow_client()
 
-    await client.update_ci(
-        project.gitlab_project_id, project.name, job_yaml, description
-    )
+    await client.update_ci(project.gitlab_project_id, project.name, job_yaml, description)
     workflow_run = await client.run_pipeline(
         project.gitlab_project_id, project.name, wait=sync, include_output=sync
     )
